@@ -11,12 +11,12 @@
 // terms of the GNU Lesser General Public License as published by the Free
 // Software Foundation; either version 2.1 of the License, or (at your
 // option) any later version.
-// 
+//
 // This software is distributed in the hope that it will be useful, but
 // WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 // or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 // License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public License
 // along with this software; if not, write to the Free Software Foundation,
 // Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
@@ -37,11 +37,9 @@
 
 // U.S. Government Sponsorship under NASA Contract
 // NAS7-1260 is acknowledged.
-// 
+//
 // Author: Todd.K.Karakashian@jpl.nasa.gov
 //
-// $RCSfile: hcstream.h,v $ - stream class declarations for HDFClass
-// 
 //////////////////////////////////////////////////////////////////////////////
 
 #include <string>
@@ -54,10 +52,11 @@ class hdfistream_obj {          // base class for streams reading HDF objects
   public:
     hdfistream_obj(const string filename = "") {
         _init(filename);
-    } hdfistream_obj(const hdfistream_obj &) {
+    }
+    hdfistream_obj(const hdfistream_obj &) {
         THROW(hcerr_copystream);
     }
-    virtual ~ hdfistream_obj(void) {
+    virtual ~hdfistream_obj(void) {
     }
     void operator=(const hdfistream_obj &) {
         THROW(hcerr_copystream);
@@ -71,7 +70,7 @@ class hdfistream_obj {          // base class for streams reading HDF objects
     virtual bool eos(void) const = 0;   // are we at end of stream?
     virtual int index(void) const {
         return _index;
-  } // return current position protected:
+    } // return current position protected:
     void _init(const string filename = "") {
         if (filename.length())
             _filename = filename;
@@ -83,11 +82,13 @@ class hdfistream_obj {          // base class for streams reading HDF objects
 };
 
 class hdfistream_sds:public hdfistream_obj {
+  
   public:
     hdfistream_sds(const string filename = "");
-     hdfistream_sds(const hdfistream_sds &):hdfistream_obj(*this) {
+    hdfistream_sds(const hdfistream_sds &):hdfistream_obj(*this) {
         THROW(hcerr_copystream);
-    } virtual ~ hdfistream_sds(void) {
+    }
+    virtual ~ hdfistream_sds(void) {
         _del();
     }
     void operator=(const hdfistream_sds &) {
@@ -165,16 +166,16 @@ class hdfistream_sds:public hdfistream_obj {
         int32 edge[hdfclass::MAXDIMS];
         int32 stride[hdfclass::MAXDIMS];
     } _slab;
-    // Since an SDS can hold a Grid, there may be several different
+    // Since a SDS can hold a Grid, there may be several different
     // constraints (because a client might constrain each of the fields
-    // differently an want a Structure object back). I've added a vector of
+    // differently and want a Structure object back). I've added a vector of
     // array_ce objects to hold all this CE information so that the
-    // operator>> method will be able to access it at the corrrect time. This
+    // operator>> method will be able to access it at the correct time. This
     // new object holds only the information about constraints on the Grid's
     // map vectors. The _slab member will hold the constraint on the Grid's
-    // array. Note that the in many cases the constraints on the maps can be
-    // derived frm the array's constraints, but sometimes a client will only
-    // ask for the maps and thus the array's constaint will be the entire
+    // array. Note that in many cases the constraints on the maps can be
+    // derived from the array's constraints, but sometimes a client will only
+    // ask for the maps and thus the array's constraint will be the entire
     // array (the `default constraint').
     vector < array_ce > _map_ce_vec;    // Added 2/5/2002 jhrg
     bool _map_ce_set;
@@ -184,10 +185,11 @@ class hdfistream_sds:public hdfistream_obj {
 class hdfistream_annot:public hdfistream_obj {
   public:
     hdfistream_annot(const string filename = "");
-     hdfistream_annot(const string filename, int32 tag, int32 ref);
-     hdfistream_annot(const hdfistream_annot &):hdfistream_obj(*this) {
+    hdfistream_annot(const string filename, int32 tag, int32 ref);
+    hdfistream_annot(const hdfistream_annot &):hdfistream_obj(*this) {
         THROW(hcerr_copystream);
-    } virtual ~ hdfistream_annot(void) {
+    }
+     virtual ~ hdfistream_annot(void) {
         _del();
     }
     void operator=(const hdfistream_annot &) {
@@ -206,9 +208,11 @@ class hdfistream_annot:public hdfistream_obj {
     }                           // position to next annot
     virtual bool eos(void) const {
         return (_index >= (int) _an_ids.size());
-    } virtual bool bos(void) const {
+    }
+    virtual bool bos(void) const {
         return (_index <= 0);
-    } virtual void rewind(void) {
+    }
+    virtual void rewind(void) {
         _index = 0;
     }
     virtual void set_annot_type(bool label, bool desc)  // specify types of
@@ -241,9 +245,10 @@ class hdfistream_annot:public hdfistream_obj {
 class hdfistream_vdata:public hdfistream_obj {
   public:
     hdfistream_vdata(const string filename = "");
-     hdfistream_vdata(const hdfistream_vdata &):hdfistream_obj(*this) {
+    hdfistream_vdata(const hdfistream_vdata &) : hdfistream_obj(*this) {
         THROW(hcerr_copystream);
-    } virtual ~ hdfistream_vdata(void) {
+    }
+    virtual ~hdfistream_vdata(void) {
         _del();
     }
     void operator=(const hdfistream_vdata &) {
@@ -265,10 +270,12 @@ class hdfistream_vdata:public hdfistream_obj {
     virtual bool bos(void) const        // positioned in front of the first Vdata?
     {
         return (_index <= 0);
-    } virtual bool eos(void) const      // positioned past the last Vdata?
+    }
+    virtual bool eos(void) const      // positioned past the last Vdata?
     {
         return (_index >= (int) _vdata_refs.size());
-    } virtual bool eo_attr(void) const; // positioned past the last attribute?
+    }
+    virtual bool eo_attr(void) const; // positioned past the last attribute?
     void setmeta(bool val) {
         _meta = val;
     }                           // set metadata loading
@@ -310,9 +317,10 @@ class hdfistream_vdata:public hdfistream_obj {
 class hdfistream_vgroup:public hdfistream_obj {
   public:
     hdfistream_vgroup(const string filename = "");
-     hdfistream_vgroup(const hdfistream_vgroup &):hdfistream_obj(*this) {
+    hdfistream_vgroup(const hdfistream_vgroup &):hdfistream_obj(*this) {
         THROW(hcerr_copystream);
-    } virtual ~ hdfistream_vgroup(void) {
+    }
+    virtual ~hdfistream_vgroup(void) {
         _del();
     }
     void operator=(const hdfistream_vgroup &) {
@@ -335,10 +343,12 @@ class hdfistream_vgroup:public hdfistream_obj {
     virtual bool bos(void) const        // positioned in front of the first Vgroup?
     {
         return (_index <= 0);
-    } virtual bool eos(void) const      // positioned past the last Vgroup?
+    }
+    virtual bool eos(void) const      // positioned past the last Vgroup?
     {
         return (_index >= (int) _vgroup_refs.size());
-    } virtual bool eo_attr(void) const; // positioned past the last attribute?
+    }
+    virtual bool eo_attr(void) const; // positioned past the last attribute?
     void setmeta(bool val) {
         _meta = val;
     }                           // set metadata loading
@@ -363,7 +373,9 @@ class hdfistream_vgroup:public hdfistream_obj {
     }
     string _memberName(int32 ref);      // find the name of ref'd Vgroup in the stream
     int32 _vgroup_id;           // handle of open object in annotation interface
+#if 0
     int32 _member_id;           // handle of child object in this Vgroup
+#endif
     int32 _attr_index;          // index of current attribute
     int32 _nattrs;              // number of attributes for this Vgroup
     bool _meta;
@@ -379,9 +391,10 @@ class hdfistream_vgroup:public hdfistream_obj {
 class hdfistream_gri:public hdfistream_obj {
   public:
     hdfistream_gri(const string filename = "");
-     hdfistream_gri(const hdfistream_gri &):hdfistream_obj(*this) {
+    hdfistream_gri(const hdfistream_gri &):hdfistream_obj(*this) {
         THROW(hcerr_copystream);
-    } virtual ~ hdfistream_gri(void) {
+    }
+    virtual ~ hdfistream_gri(void) {
         _del();
     }
     void operator=(const hdfistream_gri &) {
@@ -428,7 +441,7 @@ class hdfistream_gri:public hdfistream_obj {
         _attr_index = _pal_index = 0;
     }
     int32 _gr_id;               // GR interface id -> can't get rid of this, needed for GRend()
-    int32 _ri_id;               // handle for open raster object 
+    int32 _ri_id;               // handle for open raster object
     int32 _attr_index;          // index to current attribute
     int32 _pal_index;           // index to current palette
     int32 _nri;                 // number of rasters in the stream
@@ -446,99 +459,5 @@ class hdfistream_gri:public hdfistream_obj {
     } _slab;
 };                              /* Note: multiple palettes is not supported in the current HDF 4.0 GR API */
 
-// $Log: hcstream.h,v $
-// Revision 1.9.4.1  2003/05/21 16:26:58  edavis
-// Updated/corrected copyright statements.
-//
-// Revision 1.9  2003/01/31 02:08:37  jimg
-// Merged with release-3-2-7.
-//
-// Revision 1.7.4.4  2002/02/12 20:09:13  jimg
-// Fix for the latest Grid Map Vector fix. When an SDS is built for an Array
-// (not a Grid) there are no map vectors to work with so the array_ce info
-// must be protected. By default an hdfistream initializes a flag as false that
-// the operator>> methods check before using the saved map vector CEs.
-//
-// Revision 1.7.4.3  2002/02/05 17:46:17  jimg
-// Added struct array_ce to hold a single array constaint.
-// Added _map_ce_vec, a vector<array_ce> object to hdfistream_sds so that
-// instances no longer use the constraint associated with a Grid's array
-// when sending map vectors. This is necessary because some clients ask
-// for just map vectors and the array constraint (which defaults to the
-// whole array) overrides the actual constraint(s) sent by the client.
-//
-// Revision 1.7.4.2  2002/01/29 20:33:02  dan
-// Added new elements to hdf_vgroup structure to maintain
-// member variable names (string-reps) to couple explicit
-// variable names to tag/ref fields in the structure.  Required
-// to support new Ancillary DDS usage.
-//
-// Revision 1.8  2001/08/27 17:21:34  jimg
-// Merged with version 3.2.2
-//
-// Revision 1.7.4.1  2001/05/15 17:54:47  dan
-// Added hdfistream_vdata method isInternalVdata.
-//
-// Revision 1.7  2000/10/09 19:46:19  jimg
-// Moved the CVS Log entries to the end of each file.
-// Added code to catch Error objects thrown by the dap library.
-// Changed the read() method's definition to match the dap library.
-//
-// Revision 1.6  1999/05/06 03:23:33  jimg
-// Merged changes from no-gnu branch
-//
-// Revision 1.5  1999/05/05 23:33:43  jimg
-// String --> string conversion
-//
-// Revision 1.4.6.1  1999/05/06 00:35:45  jimg
-// Jakes String --> string changes
-//
-// Revision 1.4  1998/09/10 23:03:46  jehamby
-// Add support for Vdata and Vgroup attributes
-//
-// Revision 1.3  1998/07/13 20:26:35  jimg
-// Fixes from the final test of the new build process
-//
-// Revision 1.2.4.1  1998/05/22 19:50:52  jimg
-// Patch from Jake Hamby to support subsetting raster images
-//
-// Revision 1.2  1998/04/03 18:34:18  jimg
-// Fixes for vgroups and Sequences from Jake Hamby
-//
-// Revision 1.1  1996/10/31 18:43:01  jimg
-// Added.
-//
-// Revision 1.10  1996/09/20  17:53:42  ike
-// Added setinterlace() and _interlace_mode to hdfistream_gri.
-//
-// Revision 1.9  1996/08/14  22:36:17  ike
-// Added hdfistream_vdata:setrecs().
-//
-// Revision 1.8  1996/08/14  17:56:37  todd
-// Added slab setting member function, slab protected data member to hdfistream_sds.
-//
-// Revision 1.7  1996/07/22  17:13:30  todd
-// Const-corrected hdfistream_gri::seek() declaration.
-//
-// Revision 1.6  1996/06/19  18:28:39  todd
-// Fixed a bug in _rewind which caused a core dump if there were no Vdata's in the stream.
-//
-// Revision 1.5  1996/06/18  21:53:55  todd
-// Removed one constructor to be consistent with the interfaces of the other stream
-// classes.
-//
-// Revision 1.4  1996/06/14  23:18:27  ike
-// Added hdfistream_gri stream class.
-//
-// Revision 1.3  1996/06/14  23:07:18  todd
-// Added copyright statement.
-// Added support for Vdata.
-//
-// Revision 1.2  1996/04/19  17:40:18  todd
-// Added seek(const char *) and _seek_arr(const string&) mfuncs.
-// Added a cast in the eos() mfunc to silence g++'s warning.
-//
-// Revision 1.1  1996/04/19  01:17:02  todd
-// Initial revision
-//
 #endif                          // ifndef _HCSTREAM_H
+
