@@ -7,12 +7,12 @@
 // terms of the GNU Lesser General Public License as published by the Free
 // Software Foundation; either version 2.1 of the License, or (at your
 // option) any later version.
-// 
+//
 // This software is distributed in the hope that it will be useful, but
 // WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 // or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public
 // License for more details.
-// 
+//
 // You should have received a copy of the GNU Lesser General Public License
 // along with this software; if not, write to the Free Software Foundation,
 // Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
@@ -34,11 +34,11 @@
 
 // U.S. Government Sponsorship under NASA Contract
 // NAS7-1260 is acknowledged.
-// 
+//
 // Author: Todd.K.Karakashian@jpl.nasa.gov
 //
 // $RCSfile: sds.cc,v $ - input stream class for HDF SDS
-// 
+//
 //////////////////////////////////////////////////////////////////////////////
 
 #include "config_hdf.h"
@@ -53,12 +53,12 @@
 #include <vector>
 #include <algorithm>
 #include <functional>
+#include <cerrno>
 
 #include <hcstream.h>
 #include <hdfclass.h>
 
-//#define DODS_DEBUG
-#include <debug.h>
+#include <BESDebug.h>
 
 using std::cerr;
 using std::endl;
@@ -127,7 +127,18 @@ void hdfistream_sds::_close_sds(void)
 // find the next SDS array (not necessarily the next SDS) in the file
 void hdfistream_sds::_seek_next_arr(void)
 {
+    if (_sds_id != 0) {
+        BESDEBUG("h4", "hdfistream_sds::_seek_next_arr called with an open sds: "
+                 << _sds_id << endl);
+        SDendaccess(_sds_id);
+        _sds_id = 0;
+    }
+
     for (_index++, _dim_index = _attr_index = 0; _index < _nsds; ++_index) {
+        if (_sds_id != 0) {
+            BESDEBUG("h4", "hdfistream_sds::_seek_next_arr inside for-loop with an open sds: "
+                     << _sds_id << endl);
+        }
         if ((_sds_id = SDselect(_file_id, _index)) < 0)
             THROW(hcerr_sdsopen);
         if (!SDiscoordvar(_sds_id))
@@ -148,9 +159,14 @@ void hdfistream_sds::_seek_arr(int arr_index)
 // find the SDS array with specified name
 void hdfistream_sds::_seek_arr(const string & name)
 {
+    if (_sds_id != 0) {
+        BESDEBUG("h4", "hdfistream_sds::_seek_arr called with an open sds: "
+                 << _sds_id << endl);
+        _close_sds();
+    }
+
     int index;
     const char *nm = name.c_str();
-
     if ((index = SDnametoindex(_file_id, (char *) nm)) < 0)
         THROW(hcerr_sdsfind);
     if ((_sds_id = SDselect(_file_id, index)) < 0)
@@ -168,8 +184,13 @@ void hdfistream_sds::_seek_arr(const string & name)
 // find the SDS array with specified ref
 void hdfistream_sds::_seek_arr_ref(int ref)
 {
-    int index;
+    if (_sds_id != 0) {
+        BESDEBUG("h4", "hdfistream_sds::_seek_arr_ref called with an open sds: "
+                 << _sds_id << endl);
+        _close_sds();
+    }
 
+    int index;
     if ((index = SDreftoindex(_file_id, ref)) < 0)
         THROW(hcerr_sdsfind);
     if ((_sds_id = SDselect(_file_id, index)) < 0)
@@ -259,15 +280,21 @@ bool hdfistream_sds::eo_dim(void) const
     }
 }
 
-// open a new file 
+// open a new file
 void hdfistream_sds::open(const char *filename)
 {
     if (filename == 0)          // no filename given
         THROW(hcerr_openfile);
+    BESDEBUG("h4", "sds opening file " << filename << endl);
     if (_file_id != 0)          // close any currently open file
         close();
     if ((_file_id = SDstart((char *) filename, DFACC_READ)) < 0)
+    {
         THROW(hcerr_openfile);
+    }
+
+    BESDEBUG("h4", "sds file opened: id=" << _file_id << endl);
+
     _filename = filename;       // assign filename
     _get_fileinfo();            // get file information
     rewind();                   // position at BOS to start
@@ -277,6 +304,8 @@ void hdfistream_sds::open(const char *filename)
 // close currently open file (if any)
 void hdfistream_sds::close(void)
 {                               // close file
+    BESDEBUG("h4", "sds file closed: id=" << _file_id << ", this: " << this<< endl);
+
     _close_sds();               // close any currently open SDS
     if (_file_id != 0)          // if open file, then close it
         (void) SDend(_file_id);
@@ -363,11 +392,11 @@ void hdfistream_sds::setslab(vector < int >start, vector < int >edge,
 
 // This function, when compiled with gcc 2.8 and -O2, causes a virtual
 // memory exceeded error. 2/25/98 jhrg
-// load currently open SDS into an hdf_sds object       
+// load currently open SDS into an hdf_sds object
 hdfistream_sds & hdfistream_sds::operator>>(hdf_sds & hs)
 {
 
-    // delete any prevous data in hs
+    // delete any previous data in hs
     hs.dims = vector < hdf_dim > ();
     hs.attrs = vector < hdf_attr > ();
     hs.data = hdf_genvec();
@@ -396,7 +425,6 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_sds & hs)
     *this >> hs.dims;
     *this >> hs.attrs;
     hs.name = name;             // assign SDS name
-
     char *data = 0;
     int nelts = 1;
     if (_meta)                  // if _meta is set, just load type information
@@ -406,12 +434,12 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_sds & hs)
             for (int i = 0; i < rank; ++i)
                 nelts *= _slab.edge[i];
 
-            // allocate a temporray C array to hold the data from SDreaddata()
+            // allocate a temporary C array to hold the data from SDreaddata()
             int datasize = nelts * DFKNTsize(number_type);
             data = new char[datasize];
             if (data == 0)
                 THROW(hcerr_nomemory);
-            DBG(cerr << "SDreaddata() on line 387. _sds_id: " << _sds_id
+            BESDEBUG("h4", "SDreaddata() on line 387. _sds_id: " << _sds_id
                 << endl);
             if (SDreaddata(_sds_id, _slab.start, _slab.stride, _slab.edge,
                            data) < 0) {
@@ -427,7 +455,7 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_sds & hs)
                 nelts *= dim_sizes[i];
             }
 
-            // allocate a temporray C array to hold the data from SDreaddata()
+            // allocate a temporary C array to hold the data from SDreaddata()
             int datasize = nelts * DFKNTsize(number_type);
             data = new char[datasize];
             if (data == 0)
@@ -449,7 +477,7 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_sds & hs)
 }
 
 // Functor to help look for a particular map's ce in the vector of array_ce
-// objects. 
+// objects.
 class ce_name_match:public std::unary_function < array_ce, bool > {
     string name;
   public:
@@ -459,7 +487,7 @@ class ce_name_match:public std::unary_function < array_ce, bool > {
     }
 };
 
-// load dimension currently positioned at 
+// load dimension currently positioned at
 hdfistream_sds & hdfistream_sds::operator>>(hdf_dim & hd)
 {
 
@@ -481,8 +509,8 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_dim & hd)
     // constraint is the default (the whole array) and so there'll be no
     // reduction in rank. 2/5/2002 jhrg
     //
-    // if reduce_rank is true, hyperslab dimensions of length 1 will be 
-    // eliminated from the dimension object, thus reducing the rank of the 
+    // if reduce_rank is true, hyperslab dimensions of length 1 will be
+    // eliminated from the dimension object, thus reducing the rank of the
     // hyperslab
     while (_slab.set && _slab.reduce_rank && !eo_dim() &&
            _slab.edge[_dim_index] == 1)
@@ -519,7 +547,7 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_dim & hd)
     slab s = _slab;
     if (is_map_ce_set()) {      // Only go here if the map_ce_vec has been
         // set. The is_map_ce_set() predicate is
-        // false by default. 
+        // false by default.
 #if 0
         cerr << "dim name: " << name << endl;
         cerr << "slab set: " << _slab.set << endl;
@@ -578,12 +606,12 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_dim & hd)
         if (number_type != 0) { // found a dimension scale
 
             /*
-             *  Currently, this server cannot support dimension scales 
+             *  Currently, this server cannot support dimension scales
              *  that are stored as character arrays. See bugs 748 and 756.
              */
             if (number_type != DFNT_CHAR) {
                 // allocate a temporary C array to hold data from
-                // SDgetdimscale() 
+                // SDgetdimscale()
                 char *data = new char[count * DFKNTsize(number_type)];
 
                 if (data == 0)
@@ -626,7 +654,7 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_dim & hd)
     return *this;
 }
 
-// load attribute currently positioned at 
+// load attribute currently positioned at
 hdfistream_sds & hdfistream_sds::operator>>(hdf_attr & ha)
 {
 
@@ -642,12 +670,12 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_attr & ha)
     // prepare to read attribute information: set nattrs, id depending on whether
     // reading file attributes or SDS attributes
     int32 id;
-    int nattrs;
+    //int nattrs;
     if (bos()) {                // if at BOS, then read file attributes
-        nattrs = _nfattrs;
+        //nattrs = _nfattrs;
         id = _file_id;
     } else {                    // else read SDS attributes
-        nattrs = _nattrs;
+        //nattrs = _nattrs;
         id = _sds_id;
     }
     char name[hdfclass::MAXSTR];
@@ -666,7 +694,7 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_attr & ha)
         delete[]data;           // problem: clean up and throw an exception
         THROW(hcerr_sdsinfo);
     }
-    // eliminate trailing null characters from the data string; 
+    // eliminate trailing null characters from the data string;
     // they cause GNU's String class problems
     // NOTE: removed because count=0 if initial char is '\0' and we're not
     //   using GNU String anymore
@@ -693,7 +721,7 @@ hdfistream_sds & hdfistream_sds::operator>>(hdf_attr & ha)
 }
 
 // This function, when compiled with gcc 2.8 and -O2, causes a virtual
-// memeory exceeded error. 2/25/98 jhrg
+// Memory exceeded error. 2/25/98 jhrg
 // read in all the SDS arrays in a file
 hdfistream_sds & hdfistream_sds::operator>>(vector < hdf_sds > &hsv)
 {
@@ -764,147 +792,3 @@ bool hdf_sds::_ok(bool * has_scale) const
 
     return true;
 }
-
-// $Log: sds.cc,v $
-// Revision 1.13.4.1.2.3  2004/07/06 20:07:32  jimg
-// Added note about bug 748/756.
-//
-// Revision 1.13.4.1.2.2  2004/04/08 20:13:29  dan
-// Modified overloaded extraction operator for SDS dimensions in
-// hdfclass/sds.cc [hdfistream_sds& hdfistream_sds::operator>>(hdf_dim &hd)]
-// to ignore the case when an SDS dimension scale contains
-// character datatypes.  First report of this problem was for
-// MODIS GeoLocation Products, SDS name 'Scan Type', which is of
-// size char8(nscans,10), with potential values of 'Day', 'Night', 'Other'.
-//
-// Revision 1.13.4.1.2.1  2004/02/23 02:08:03  rmorris
-// There is some incompatibility between the use of isascii() in the hdf library
-// and its use on OS X.  Here we force in the #undef of isascii in the osx case.
-//
-// Revision 1.13.4.1  2003/05/21 16:26:58  edavis
-// Updated/corrected copyright statements.
-//
-// Revision 1.13  2003/01/31 02:08:37  jimg
-// Merged with release-3-2-7.
-//
-// Revision 1.12.4.3  2002/02/12 20:09:13  jimg
-// Fix for the latest Grid Map Vector fix. When an SDS is built for an Array
-// (not a Grid) there are no map vectors to work with so the array_ce info
-// must be protected. By default an hdfistream initializes a flag as false that
-// the operator>> methods check before using the saved map vector CEs.
-//
-// Revision 1.12.4.2  2002/02/05 17:30:07  jimg
-// I changed hdfistream_sds so that it can hold a vector<array_ce> object. The
-// operator>>(hdf_dim&) method now uses this new object to correctly set the
-// hdfistream_sds::_slab member when maps are requested but the array is not.
-// Currently 17 tests (run make check after installing the server and the test
-// datasets) fail.
-//
-// Revision 1.12.4.1  2001/10/30 06:36:35  jimg
-// Added genvec::append(...) method.
-// Fixed up some comments in genvec.
-// Changed genvec's data member from void * to char * to quell warnings
-// about void * being passed to delete.
-//
-// Revision 1.12  2000/10/09 19:46:19  jimg
-// Moved the CVS Log entries to the end of each file.
-// Added code to catch Error objects thrown by the dap library.
-// Changed the read() method's definition to match the dap library.
-//
-// Revision 1.11  1999/05/06 03:23:33  jimg
-// Merged changes from no-gnu branch
-//
-// Revision 1.10  1999/05/05 23:33:43  jimg
-// String --> string conversion
-//
-// Revision 1.9.6.1  1999/05/06 00:35:45  jimg
-// Jakes String --> string changes
-//
-// Revision 1.9  1998/09/10 23:11:25  jehamby
-// Fix for SDS not outputting global attributes if no SDS's are in the dataset
-//
-// Revision 1.8  1998/09/10 21:33:24  jehamby
-// Map DFNT_CHAR8 and DFNT_UCHAR8 to Byte instead of string in SDS.
-//
-// Revision 1.7  1998/04/03 18:34:19  jimg
-// Fixes for vgroups and Sequences from Jake Hamby
-//
-// Revision 1.6  1998/03/26 00:29:34  jimg
-// Fixed bug in _ok() where has_scale was incorrectly dereferenced. The pointer
-// was supposed to be tested and then dereferenced, but instead was dereferenced
-// first. Pointed out by Jake Hamby.
-//
-// Revision 1.5  1998/03/17 18:01:02  jimg
-// Added comments about virtual memory error when compiling
-//
-// Revision 1.4  1997/12/16 01:46:46  jimg
-// Merged release 2.14d changes
-//
-// Revision 1.3  1997/10/04 00:33:10  jimg
-// Release 2.14c fixes
-//
-// Revision 1.2.6.1  1997/09/05 21:28:05  jimg
-// Fixed _ok() so that if `has_scale' is null (the default) it is not
-// dereferenced.
-//
-// Applied Todd's patch for the `stride bug' (See the TODO list).
-//
-// Revision 1.1  1996/10/31 18:43:06  jimg
-// Added.
-//
-// Revision 1.15  1996/10/14 19:06:14  todd
-// Minor fix to support compilation on Sun platform.
-//
-// Revision 1.14  1996/09/23 23:46:18  todd
-// Fixed hdfistream_sds::operator>>(hdf_dim&) to correctly read size of
-// unlimited dimensions.
-//
-// Revision 1.13  1996/09/23  22:50:51  todd
-// Fixed bug in checking of dimension scales.
-//
-// Revision 1.12  1996/09/17  23:21:56  todd
-// Added support for reading subsets of SDS's to hdfistream_sds.
-//
-// Revision 1.11  1996/07/19  23:21:59  todd
-// Fixed bug in dimension and attribute indexing.
-//
-// Revision 1.10  1996/06/14  23:12:02  todd
-// Fixed minor bug in operator>>().
-//
-// Revision 1.9  1996/05/23  18:17:55  todd
-// Added copyright statement.
-//
-// Revision 1.8  1996/05/08  15:48:38  todd
-// Moved hdf_sds::has_scale() into this module and modified it to use the new _ok mfunc.
-// Added new _ok protected mfunc which verifies that an hdf_sds is in an OK state.
-//
-// Revision 1.7  1996/05/06  17:32:34  todd
-// Fixed a bug in the patch applied to operator>>(hdf_attr&).
-//
-// Revision 1.6  1996/05/03  22:50:03  todd
-// Added a patch to the operator>>(hdf_attr&) mfunc to strip away any null characters
-// that are padded onto the end of an attribute.  For some strange reason,
-// AVHRR Pathfinder SST files seem to have a null character padded at the end of the
-// values of text attributes.  This caused problems when the text was loaded into
-// libg++ strings.
-//
-// Revision 1.5  1996/04/19  17:36:19  todd
-// Added public mfunc seek(const char *) and protected mfunc _seek_arr(const string&)
-// which is used in implementing t.
-//
-// Revision 1.4  1996/04/19  01:14:28  todd
-// Changed eof, bof to eos, bos (end of stream).  That is better terminology, since
-// a stream of SDS's does not correspond to the entire HDF file.
-//
-// Revision 1.3  1996/04/09  23:28:44  todd
-// Modified so open() is called by constructor and not by _init().  This makes the
-// semantics of _init() more logical and consistent with hdfistream_annot.
-//
-// Revision 1.2  1996/04/04  01:41:30  todd
-// Fixed operator>>(hdf_dim&) so it would tolerate a failure of SDgetdimstrs().
-// Fixed operator>>(hdf_sds&) to allow storage of type information in zero-length
-// hdf_genvec if _meta is set.
-//
-// Revision 1.1  1996/04/02  21:47:22  todd
-// Initial revision
-//
