@@ -1,24 +1,23 @@
-/* A Bison parser, made by GNU Bison 2.3.  */
+
+/* A Bison parser, made by GNU Bison 2.4.1.  */
 
 /* Skeleton implementation for Bison's Yacc-like parsers in C
-
-   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
+   
+      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
    Free Software Foundation, Inc.
-
-   This program is free software; you can redistribute it and/or modify
+   
+   This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
-   the Free Software Foundation; either version 2, or (at your option)
-   any later version.
-
+   the Free Software Foundation, either version 3 of the License, or
+   (at your option) any later version.
+   
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-
+   
    You should have received a copy of the GNU General Public License
-   along with this program; if not, write to the Free Software
-   Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.  */
+   along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
 /* As a special exception, you may create a larger work that contains
    part or all of the Bison parser skeleton and distribute that work
@@ -29,7 +28,7 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-
+   
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
@@ -47,7 +46,7 @@
 #define YYBISON 1
 
 /* Bison version.  */
-#define YYBISON_VERSION "2.3"
+#define YYBISON_VERSION "2.4.1"
 
 /* Skeleton name.  */
 #define YYSKELETON_NAME "yacc.c"
@@ -55,58 +54,35 @@
 /* Pure parsers.  */
 #define YYPURE 0
 
+/* Push parsers.  */
+#define YYPUSH 0
+
+/* Pull parsers.  */
+#define YYPULL 1
+
 /* Using locations.  */
 #define YYLSP_NEEDED 0
 
 /* Substitute the variable and function names.  */
-#define yyparse hdfeosparse
-#define yylex   hdfeoslex
-#define yyerror hdfeoserror
-#define yylval  hdfeoslval
-#define yychar  hdfeoschar
-#define yydebug hdfeosdebug
-#define yynerrs hdfeosnerrs
-
-
-/* Tokens.  */
-#ifndef YYTOKENTYPE
-# define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     GROUP = 258,
-     END_GROUP = 259,
-     OBJECT = 260,
-     END_OBJECT = 261,
-     END = 262,
-     INT = 263,
-     FLOAT = 264,
-     STR = 265,
-     COMMENT = 266
-   };
-#endif
-/* Tokens.  */
-#define GROUP 258
-#define END_GROUP 259
-#define OBJECT 260
-#define END_OBJECT 261
-#define END 262
-#define INT 263
-#define FLOAT 264
-#define STR 265
-#define COMMENT 266
-
-
+#define yyparse         hdfeosparse
+#define yylex           hdfeoslex
+#define yyerror         hdfeoserror
+#define yylval          hdfeoslval
+#define yychar          hdfeoschar
+#define yydebug         hdfeosdebug
+#define yynerrs         hdfeosnerrs
 
 
 /* Copy the first part of user declarations.  */
+
+/* Line 189 of yacc.c  */
 #line 31 "hdfeos.y"
 
 
 #define YYSTYPE char *
 #define YYDEBUG 1
 
-// static char rcsid[] not_used = {"$Id: hdfeos.y 18005 2008-02-14 23:23:27Z jimg $"};
+// static char rcsid[] not_used = {"$Id: hdfeos.y 22052 2010-02-01 21:48:44Z jimg $"};
 
 #include <stdio.h>
 #include <stdlib.h>
@@ -123,7 +99,7 @@ using namespace std;
 #include "Error.h"
 #include "debug.h"
 #include "parser.h"
-#include "hdfeos.tab.h"
+#include "hdfeos.tab.hh"
 
 #ifdef TRACE_NEW
 #include "trace_new.h"
@@ -164,17 +140,20 @@ static vector<AttrTable *> *attr_tab_stack;
 
 #define TYPE_NAME_VALUE(x) type << " " << name << " " << (x)
 
-static char *NO_DAS_MSG =
+static const char *NO_DAS_MSG =
 "The attribute object returned from the dataset was null\n\
 Check that the URL is correct.";
 
 void mem_list_report();
 int hdfeoslex(void);
-void hdfeoserror(char *s);
+void hdfeoserror(const char *s);
 static void process_group(parser_arg *arg, const string &s);
 
 
 
+/* Line 189 of yacc.c  */
+#line 156 "hdfeos.tab.cc"
+
 /* Enabling traces.  */
 #ifndef YYDEBUG
 # define YYDEBUG 0
@@ -193,20 +172,40 @@ static void process_group(parser_arg *arg, const string &s);
 # define YYTOKEN_TABLE 0
 #endif
 
-#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef int YYSTYPE;
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
-# define YYSTYPE_IS_DECLARED 1
-# define YYSTYPE_IS_TRIVIAL 1
+
+/* Tokens.  */
+#ifndef YYTOKENTYPE
+# define YYTOKENTYPE
+   /* Put the tokens into the symbol table, so that GDB and other debuggers
+      know about them.  */
+   enum yytokentype {
+     GROUP = 258,
+     END_GROUP = 259,
+     OBJECT = 260,
+     END_OBJECT = 261,
+     END = 262,
+     INT = 263,
+     FLOAT = 264,
+     STR = 265,
+     COMMENT = 266
+   };
 #endif
 
 
 
+#if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
+typedef int YYSTYPE;
+# define YYSTYPE_IS_TRIVIAL 1
+# define yystype YYSTYPE /* obsolescent; will be withdrawn */
+# define YYSTYPE_IS_DECLARED 1
+#endif
+
+
 /* Copy the second part of user declarations.  */
 
 
-/* Line 216 of yacc.c.  */
-#line 210 "hdfeos.tab.c"
+/* Line 264 of yacc.c  */
+#line 209 "hdfeos.tab.cc"
 
 #ifdef short
 # undef short
@@ -281,14 +280,14 @@ typedef short int yytype_int16;
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static int
-YYID (int i)
+YYID (int yyi)
 #else
 static int
-YYID (i)
-    int i;
+YYID (yyi)
+    int yyi;
 #endif
 {
-  return i;
+  return yyi;
 }
 #endif
 
@@ -369,9 +368,9 @@ void free (void *); /* INFRINGES ON USER NAME SPACE */
 /* A type that is properly aligned for any stack member.  */
 union yyalloc
 {
-  yytype_int16 yyss;
-  YYSTYPE yyvs;
-  };
+  yytype_int16 yyss_alloc;
+  YYSTYPE yyvs_alloc;
+};
 
 /* The size of the maximum gap between one aligned stack and the next.  */
 # define YYSTACK_GAP_MAXIMUM (sizeof (union yyalloc) - 1)
@@ -405,12 +404,12 @@ union yyalloc
    elements in the stack, and YYPTR gives the new location of the
    stack.  Advance YYPTR to a properly aligned location for the next
    stack.  */
-# define YYSTACK_RELOCATE(Stack)					\
+# define YYSTACK_RELOCATE(Stack_alloc, Stack)				\
     do									\
       {									\
 	YYSIZE_T yynewbytes;						\
-	YYCOPY (&yyptr->Stack, Stack, yysize);				\
-	Stack = &yyptr->Stack;						\
+	YYCOPY (&yyptr->Stack_alloc, Stack, yysize);			\
+	Stack = &yyptr->Stack_alloc;					\
 	yynewbytes = yystacksize * sizeof (*Stack) + YYSTACK_GAP_MAXIMUM; \
 	yyptr += yynewbytes / sizeof (*yyptr);				\
       }									\
@@ -501,9 +500,9 @@ static const yytype_int8 yyrhs[] =
 static const yytype_uint16 yyrline[] =
 {
        0,   158,   158,   158,   163,   167,   171,   166,   179,   183,
-     178,   191,   190,   196,   214,   230,   231,   232,   235,   236,
-     237,   238,   244,   245,   248,   272,   292,   309,   328,   345,
-     364,   364,   367,   389
+     178,   191,   190,   196,   218,   239,   240,   241,   244,   245,
+     246,   247,   253,   254,   257,   281,   301,   318,   337,   354,
+     373,   373,   376,   400
 };
 #endif
 
@@ -514,8 +513,8 @@ static const char *const yytname[] =
 {
   "$end", "error", "$undefined", "GROUP", "END_GROUP", "OBJECT",
   "END_OBJECT", "END", "INT", "FLOAT", "STR", "COMMENT", "'='", "'('",
-  "')'", "','", "$accept", "attributes", "@1", "attribute", "@2", "@3",
-  "@4", "@5", "@6", "attr_list", "data", "data2", "ints", "floats",
+  "')'", "','", "$accept", "attributes", "$@1", "attribute", "$@2", "$@3",
+  "$@4", "$@5", "$@6", "attr_list", "data", "data2", "ints", "floats",
   "floatints", "float_or_int", "strs", 0
 };
 #endif
@@ -811,17 +810,20 @@ yy_symbol_print (yyoutput, yytype, yyvaluep)
 #if (defined __STDC__ || defined __C99__FUNC__ \
      || defined __cplusplus || defined _MSC_VER)
 static void
-yy_stack_print (yytype_int16 *bottom, yytype_int16 *top)
+yy_stack_print (yytype_int16 *yybottom, yytype_int16 *yytop)
 #else
 static void
-yy_stack_print (bottom, top)
-    yytype_int16 *bottom;
-    yytype_int16 *top;
+yy_stack_print (yybottom, yytop)
+    yytype_int16 *yybottom;
+    yytype_int16 *yytop;
 #endif
 {
   YYFPRINTF (stderr, "Stack now");
-  for (; bottom <= top; ++bottom)
-    YYFPRINTF (stderr, " %d", *bottom);
+  for (; yybottom <= yytop; yybottom++)
+    {
+      int yybot = *yybottom;
+      YYFPRINTF (stderr, " %d", yybot);
+    }
   YYFPRINTF (stderr, "\n");
 }
 
@@ -855,11 +857,11 @@ yy_reduce_print (yyvsp, yyrule)
   /* The symbols being reduced.  */
   for (yyi = 0; yyi < yynrhs; yyi++)
     {
-      fprintf (stderr, "   $%d = ", yyi + 1);
+      YYFPRINTF (stderr, "   $%d = ", yyi + 1);
       yy_symbol_print (stderr, yyrhs[yyprhs[yyrule] + yyi],
 		       &(yyvsp[(yyi + 1) - (yynrhs)])
 		       		       );
-      fprintf (stderr, "\n");
+      YYFPRINTF (stderr, "\n");
     }
 }
 
@@ -1139,10 +1141,8 @@ yydestruct (yymsg, yytype, yyvaluep)
 	break;
     }
 }
-
 
 /* Prevent warnings from -Wmissing-prototypes.  */
-
 #ifdef YYPARSE_PARAM
 #if defined __STDC__ || defined __cplusplus
 int yyparse (void *YYPARSE_PARAM);
@@ -1158,11 +1158,10 @@ int yyparse ();
 #endif /* ! YYPARSE_PARAM */
 
 
-
-/* The look-ahead symbol.  */
+/* The lookahead symbol.  */
 int yychar;
 
-/* The semantic value of the look-ahead symbol.  */
+/* The semantic value of the lookahead symbol.  */
 YYSTYPE yylval;
 
 /* Number of syntax errors so far.  */
@@ -1170,9 +1169,9 @@ int yynerrs;
 
 
 
-/*----------.
-| yyparse.  |
-`----------*/
+/*-------------------------.
+| yyparse or yypush_parse.  |
+`-------------------------*/
 
 #ifdef YYPARSE_PARAM
 #if (defined __STDC__ || defined __C99__FUNC__ \
@@ -1196,14 +1195,39 @@ yyparse ()
 #endif
 #endif
 {
-  
-  int yystate;
+
+
+    int yystate;
+    /* Number of tokens to shift before error messages enabled.  */
+    int yyerrstatus;
+
+    /* The stacks and their tools:
+       `yyss': related to states.
+       `yyvs': related to semantic values.
+
+       Refer to the stacks thru separate pointers, to allow yyoverflow
+       to reallocate them elsewhere.  */
+
+    /* The state stack.  */
+    yytype_int16 yyssa[YYINITDEPTH];
+    yytype_int16 *yyss;
+    yytype_int16 *yyssp;
+
+    /* The semantic value stack.  */
+    YYSTYPE yyvsa[YYINITDEPTH];
+    YYSTYPE *yyvs;
+    YYSTYPE *yyvsp;
+
+    YYSIZE_T yystacksize;
+
   int yyn;
   int yyresult;
-  /* Number of tokens to shift before error messages enabled.  */
-  int yyerrstatus;
-  /* Look-ahead token as an internal (translated) token number.  */
-  int yytoken = 0;
+  /* Lookahead token as an internal (translated) token number.  */
+  int yytoken;
+  /* The variables used to return semantic value and location from the
+     action routines.  */
+  YYSTYPE yyval;
+
 #if YYERROR_VERBOSE
   /* Buffer for error messages, and its allocated size.  */
   char yymsgbuf[128];
@@ -1211,51 +1235,28 @@ yyparse ()
   YYSIZE_T yymsg_alloc = sizeof yymsgbuf;
 #endif
 
-  /* Three stacks and their tools:
-     `yyss': related to states,
-     `yyvs': related to semantic values,
-     `yyls': related to locations.
-
-     Refer to the stacks thru separate pointers, to allow yyoverflow
-     to reallocate them elsewhere.  */
-
-  /* The state stack.  */
-  yytype_int16 yyssa[YYINITDEPTH];
-  yytype_int16 *yyss = yyssa;
-  yytype_int16 *yyssp;
-
-  /* The semantic value stack.  */
-  YYSTYPE yyvsa[YYINITDEPTH];
-  YYSTYPE *yyvs = yyvsa;
-  YYSTYPE *yyvsp;
-
-
-
 #define YYPOPSTACK(N)   (yyvsp -= (N), yyssp -= (N))
 
-  YYSIZE_T yystacksize = YYINITDEPTH;
-
-  /* The variables used to return semantic value and location from the
-     action routines.  */
-  YYSTYPE yyval;
-
-
   /* The number of symbols on the RHS of the reduced rule.
      Keep to zero when no symbol should be popped.  */
   int yylen = 0;
 
+  yytoken = 0;
+  yyss = yyssa;
+  yyvs = yyvsa;
+  yystacksize = YYINITDEPTH;
+
   YYDPRINTF ((stderr, "Starting parse\n"));
 
   yystate = 0;
   yyerrstatus = 0;
   yynerrs = 0;
-  yychar = YYEMPTY;		/* Cause a token to be read.  */
+  yychar = YYEMPTY; /* Cause a token to be read.  */
 
   /* Initialize stack pointers.
      Waste one element of value and location stack
      so that they stay on the same level as the state stack.
      The wasted elements are never initialized.  */
-
   yyssp = yyss;
   yyvsp = yyvs;
 
@@ -1285,7 +1286,6 @@ yyparse ()
 	YYSTYPE *yyvs1 = yyvs;
 	yytype_int16 *yyss1 = yyss;
 
-
 	/* Each stack pointer address is followed by the size of the
 	   data in use in that stack, in bytes.  This used to be a
 	   conditional around just the two extra args, but that might
@@ -1293,7 +1293,6 @@ yyparse ()
 	yyoverflow (YY_("memory exhausted"),
 		    &yyss1, yysize * sizeof (*yyssp),
 		    &yyvs1, yysize * sizeof (*yyvsp),
-
 		    &yystacksize);
 
 	yyss = yyss1;
@@ -1316,9 +1315,8 @@ yyparse ()
 	  (union yyalloc *) YYSTACK_ALLOC (YYSTACK_BYTES (yystacksize));
 	if (! yyptr)
 	  goto yyexhaustedlab;
-	YYSTACK_RELOCATE (yyss);
-	YYSTACK_RELOCATE (yyvs);
-
+	YYSTACK_RELOCATE (yyss_alloc, yyss);
+	YYSTACK_RELOCATE (yyvs_alloc, yyvs);
 #  undef YYSTACK_RELOCATE
 	if (yyss1 != yyssa)
 	  YYSTACK_FREE (yyss1);
@@ -1329,7 +1327,6 @@ yyparse ()
       yyssp = yyss + yysize - 1;
       yyvsp = yyvs + yysize - 1;
 
-
       YYDPRINTF ((stderr, "Stack size increased to %lu\n",
 		  (unsigned long int) yystacksize));
 
@@ -1339,6 +1336,9 @@ yyparse ()
 
   YYDPRINTF ((stderr, "Entering state %d\n", yystate));
 
+  if (yystate == YYFINAL)
+    YYACCEPT;
+
   goto yybackup;
 
 /*-----------.
@@ -1347,16 +1347,16 @@ yyparse ()
 yybackup:
 
   /* Do appropriate processing given the current state.  Read a
-     look-ahead token if we need one and don't already have one.  */
+     lookahead token if we need one and don't already have one.  */
 
-  /* First try to decide what to do without reference to look-ahead token.  */
+  /* First try to decide what to do without reference to lookahead token.  */
   yyn = yypact[yystate];
   if (yyn == YYPACT_NINF)
     goto yydefault;
 
-  /* Not known => get a look-ahead token if don't already have one.  */
+  /* Not known => get a lookahead token if don't already have one.  */
 
-  /* YYCHAR is either YYEMPTY or YYEOF or a valid look-ahead symbol.  */
+  /* YYCHAR is either YYEMPTY or YYEOF or a valid lookahead symbol.  */
   if (yychar == YYEMPTY)
     {
       YYDPRINTF ((stderr, "Reading a token: "));
@@ -1388,20 +1388,16 @@ yybackup:
       goto yyreduce;
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   /* Count tokens shifted since error; after three, turn off error
      status.  */
   if (yyerrstatus)
     yyerrstatus--;
 
-  /* Shift the look-ahead token.  */
+  /* Shift the lookahead token.  */
   YY_SYMBOL_PRINT ("Shifting", yytoken, &yylval, &yylloc);
 
-  /* Discard the shifted token unless it is eof.  */
-  if (yychar != YYEOF)
-    yychar = YYEMPTY;
+  /* Discard the shifted token.  */
+  yychar = YYEMPTY;
 
   yystate = yyn;
   *++yyvsp = yylval;
@@ -1441,6 +1437,8 @@ yyreduce:
   switch (yyn)
     {
         case 2:
+
+/* Line 1455 of yacc.c  */
 #line 158 "hdfeos.y"
     {
 		    if (!attr_tab_stack)
@@ -1449,6 +1447,8 @@ yyreduce:
     break;
 
   case 5:
+
+/* Line 1455 of yacc.c  */
 #line 167 "hdfeos.y"
     {
 		    process_group((parser_arg *)arg, (yyvsp[(3) - (3)]));
@@ -1456,6 +1456,8 @@ yyreduce:
     break;
 
   case 6:
+
+/* Line 1455 of yacc.c  */
 #line 171 "hdfeos.y"
     {
 		  /* pop top of stack; store in attr_tab */
@@ -1465,6 +1467,8 @@ yyreduce:
     break;
 
   case 8:
+
+/* Line 1455 of yacc.c  */
 #line 179 "hdfeos.y"
     {
 		    process_group((parser_arg *)arg, (yyvsp[(3) - (3)]));
@@ -1472,6 +1476,8 @@ yyreduce:
     break;
 
   case 9:
+
+/* Line 1455 of yacc.c  */
 #line 183 "hdfeos.y"
     {
 		  /* pop top of stack; store in attr_tab */
@@ -1481,6 +1487,8 @@ yyreduce:
     break;
 
   case 11:
+
+/* Line 1455 of yacc.c  */
 #line 191 "hdfeos.y"
     { 
 		    name = (yyvsp[(1) - (1)]); 
@@ -1488,11 +1496,17 @@ yyreduce:
     break;
 
   case 13:
+
+/* Line 1455 of yacc.c  */
 #line 196 "hdfeos.y"
     {
 		    ostringstream name, comment;
 		    name << "comment" << commentnum++;
+#ifdef ATTR_STRING_QUOTE_FIX
+                    comment << (yyvsp[(1) - (1)]);
+#else
 		    comment << "\"" << (yyvsp[(1) - (1)]) << "\"";
+#endif
 		    DBG(cerr << name.str() << ":" << comment.str() << endl);
 		    AttrTable *a;
 		    if (STACK_EMPTY)
@@ -1509,24 +1523,33 @@ yyreduce:
     break;
 
   case 14:
-#line 215 "hdfeos.y"
+
+/* Line 1455 of yacc.c  */
+#line 219 "hdfeos.y"
     {
 		    AttrTable *a;
 		    if (STACK_EMPTY)
 			a = ATTR_OBJ(arg);
 		    else
 			a = TOP_OF_STACK;
+#ifdef ATTR_STRING_QUOTE_FIX
+                    a->append_attr(name.c_str(), "String", 
+                                   "Error processing EOS attributes");
+#else
 		    a->append_attr(name.c_str(), "String", 
 				   "\"Error processing EOS attributes\"");
+#endif
 		    parse_error((parser_arg *)arg, NO_DAS_MSG);
 		    /* Don't abort; keep parsing to try and pick up more
-		       attribtues. 3/30/2000 jhrg */
+		       attributes. 3/30/2000 jhrg */
  		    /* YYABORT; */
 		;}
     break;
 
   case 24:
-#line 249 "hdfeos.y"
+
+/* Line 1455 of yacc.c  */
+#line 258 "hdfeos.y"
     {
 		    /* NB: On the Sun (SunOS 4) strtol does not check for */
 		    /* overflow. Thus it will never figure out that 4 */
@@ -1553,14 +1576,16 @@ yyreduce:
     break;
 
   case 25:
-#line 273 "hdfeos.y"
+
+/* Line 1455 of yacc.c  */
+#line 282 "hdfeos.y"
     {
 		    type = "Int32";
 		    DBG(cerr << "Adding INT: " << TYPE_NAME_VALUE((yyvsp[(3) - (3)])) << endl);
 		    if (!(check_int32((yyvsp[(3) - (3)]))
-			  || check_uint32((yyvsp[(1) - (3)])))) {
+			  || check_uint32((yyvsp[(3) - (3)])))) {
 			ostringstream msg;
-			msg << "`" << (yyvsp[(1) - (3)]) << "' is not an Int32 value.";
+			msg << "`" << (yyvsp[(3) - (3)]) << "' is not an Int32 value.";
 			parse_error((parser_arg *)arg, msg.str().c_str());
 			YYABORT;
 		    }
@@ -1574,7 +1599,9 @@ yyreduce:
     break;
 
   case 26:
-#line 293 "hdfeos.y"
+
+/* Line 1455 of yacc.c  */
+#line 302 "hdfeos.y"
     {
 		    type = "Float64";
 		    DBG(cerr << "Adding FLOAT: " << TYPE_NAME_VALUE((yyvsp[(1) - (1)])) << endl);
@@ -1594,7 +1621,9 @@ yyreduce:
     break;
 
   case 27:
-#line 310 "hdfeos.y"
+
+/* Line 1455 of yacc.c  */
+#line 319 "hdfeos.y"
     {
 		    type = "Float64";
 		    DBG(cerr << "Adding FLOAT: " << TYPE_NAME_VALUE((yyvsp[(3) - (3)])) << endl);
@@ -1614,7 +1643,9 @@ yyreduce:
     break;
 
   case 28:
-#line 329 "hdfeos.y"
+
+/* Line 1455 of yacc.c  */
+#line 338 "hdfeos.y"
     {
 		    type = "Float64";
 		    DBG(cerr << "Adding FLOAT: " << TYPE_NAME_VALUE((yyvsp[(1) - (1)])) << endl);
@@ -1634,13 +1665,15 @@ yyreduce:
     break;
 
   case 29:
-#line 346 "hdfeos.y"
+
+/* Line 1455 of yacc.c  */
+#line 355 "hdfeos.y"
     {
 		    type = "Float64";
 		    DBG(cerr << "Adding FLOAT: " << TYPE_NAME_VALUE((yyvsp[(3) - (3)])) << endl);
 		    if (!check_float64((yyvsp[(3) - (3)]))) {
 			ostringstream msg;
-			msg << "`" << (yyvsp[(1) - (3)]) << "' is not a Float64 value.";
+			msg << "`" << (yyvsp[(3) - (3)]) << "' is not a Float64 value.";
 			parse_error((parser_arg *)arg, msg.str().c_str());
 			YYABORT;
 		    }
@@ -1654,7 +1687,9 @@ yyreduce:
     break;
 
   case 32:
-#line 368 "hdfeos.y"
+
+/* Line 1455 of yacc.c  */
+#line 377 "hdfeos.y"
     {
 		    type = "String";
 		    DBG(cerr << "Adding STR: " << TYPE_NAME_VALUE((yyvsp[(1) - (1)])) << endl);
@@ -1664,6 +1699,7 @@ yyreduce:
 			parse_error((parser_arg *)arg, msg.str().c_str());
 			YYABORT;
 		    }
+#if 0
 		    if (name=="GridName" || name=="SwathName" || name=="PointName") {
 		      // Strip off quotes in new ID
 		      string newname = (yyvsp[(1) - (1)])+1;
@@ -1671,15 +1707,18 @@ yyreduce:
 		      // and convert embedded spaces to _
 		      string::size_type space = 0;
 		      while((space = newname.find_first_of(' ', space)) != newname.npos) {
-			newname[space] = '_';
+			     newname[space] = '_';
 		      }
  		      SECOND_IN_STACK->attr_alias(newname, last_grid_swath);
 		    }
+#endif		    
 		;}
     break;
 
   case 33:
-#line 390 "hdfeos.y"
+
+/* Line 1455 of yacc.c  */
+#line 401 "hdfeos.y"
     {
 		    type = "String";
 		    DBG(cerr << "Adding STR: " << TYPE_NAME_VALUE((yyvsp[(3) - (3)])) << endl);
@@ -1693,8 +1732,9 @@ yyreduce:
     break;
 
 
-/* Line 1267 of yacc.c.  */
-#line 1698 "hdfeos.tab.c"
+
+/* Line 1455 of yacc.c  */
+#line 1738 "hdfeos.tab.cc"
       default: break;
     }
   YY_SYMBOL_PRINT ("-> $$ =", yyr1[yyn], &yyval, &yyloc);
@@ -1705,7 +1745,6 @@ yyreduce:
 
   *++yyvsp = yyval;
 
-
   /* Now `shift' the result of the reduction.  Determine what state
      that goes to, based on the state we popped back to and the rule
      number reduced by.  */
@@ -1770,7 +1809,7 @@ yyerrlab:
 
   if (yyerrstatus == 3)
     {
-      /* If just tried and failed to reuse look-ahead token after an
+      /* If just tried and failed to reuse lookahead token after an
 	 error, discard it.  */
 
       if (yychar <= YYEOF)
@@ -1787,7 +1826,7 @@ yyerrlab:
 	}
     }
 
-  /* Else will try to reuse look-ahead token after shifting the error
+  /* Else will try to reuse lookahead token after shifting the error
      token.  */
   goto yyerrlab1;
 
@@ -1844,9 +1883,6 @@ yyerrlab1:
       YY_STACK_PRINT (yyss, yyssp);
     }
 
-  if (yyn == YYFINAL)
-    YYACCEPT;
-
   *++yyvsp = yylval;
 
 
@@ -1871,7 +1907,7 @@ yyabortlab:
   yyresult = 1;
   goto yyreturn;
 
-#ifndef yyoverflow
+#if !defined(yyoverflow) || YYERROR_VERBOSE
 /*-------------------------------------------------.
 | yyexhaustedlab -- memory exhaustion comes here.  |
 `-------------------------------------------------*/
@@ -1882,7 +1918,7 @@ yyexhaustedlab:
 #endif
 
 yyreturn:
-  if (yychar != YYEOF && yychar != YYEMPTY)
+  if (yychar != YYEMPTY)
      yydestruct ("Cleanup: discarding lookahead",
 		 yytoken, &yylval);
   /* Do not reclaim the symbols of the rule which action triggered
@@ -1908,14 +1944,16 @@ yyreturn:
 }
 
 
-#line 402 "hdfeos.y"
+
+/* Line 1675 of yacc.c  */
+#line 413 "hdfeos.y"
 
 
 // This function is required for linking, but DODS uses its own error
 // reporting mechanism.
 
 void
-hdfeoserror(char *s)
+hdfeoserror(const char *s)
 {
 }
 
